import React, {useState} from "react";
import classNames from 'classnames';
import { IconType } from 'react-icons';

type RowIconButtonProps = IconButtonProps & { className?: string; text?: string; url?: string };

type IconButtonProps = {
  icon: IconType;
  onClick(): void;
};

export const IconButton = (props: IconButtonProps) => {
  const Icon = props.icon;

  return <Icon className='ml-1 text-gray-900 cursor-pointer' onClick={props.onClick} />;
};

export const RowIconButton = ({ className, icon, text, url, onClick }: RowIconButtonProps) => {
  const [showText, setShowText] = useState<boolean>(false);
  const Icon = icon;

  const onHoverOrFocus = () => {
    setShowText(true);
  };

  const onUnhoverOrBlur = () => {
    setShowText(false);
  };

  return (
    <div className={classNames('relative', className)}>
      {showText && (
        <span
          className={classNames(
            'absolute rounded-sm px-2 py-1 bg-white shadow-sm text-gray-700 text-xs top-1/2 left-1/2 -translate-x-1/2 -translate-y-[180%] z-30'
          )}
        >
          {text}
        </span>
      )}
      <a
        href={url ?? '#'}
        className='block rounded-sm p-1 cursor-pointer hover:bg-primary-50'
        onMouseOver={onHoverOrFocus}
        onFocus={onHoverOrFocus}
        onMouseOut={onUnhoverOrBlur}
        onBlur={onUnhoverOrBlur}
        onClick={onClick}
      >
        <Icon className='text-primary-500 w-[18px] h-[18px]' />
      </a>
    </div>
  );
};